# -*- coding: utf-8 -*-
#
# rb_main.rb
# MemoStack
#
# Created by Fujimoto Hisa on 09/10/25.
# Copyright Fujimoto Hisa 2009. All rights reserved.
#

# Loading the Cocoa framework. If you need to load more frameworks, you can
# do that here too.

# MacRuby (0.4) が同梱されている場合、Rubyプログラムのロードパスをそちらに変更する
private_macruby_path = "#{NSBundle.mainBundle.privateFrameworksPath}/MacRuby.framework"
if FileTest.directory? private_macruby_path then
  $:.map! { |path| path.sub(%r{/Library/Frameworks/MacRuby.framework}, private_macruby_path) }
end

framework 'Cocoa'
require 'objc_support'
require 'app_defaults'

# printf デバッグ用メソッド
def dmesg(msgfmt='', *args)
  msg = msgfmt.to_s % args
  STDERR.puts(msg)
end

def dmesg_fl(file, line, msgfmt='', *args)
  filename = File.basename(file)
  msg = msgfmt.to_s % args
  STDERR.printf("%s:%d -- %s\n", filename, line, msg)
end

def not_impl(file, line)
  dmesg_fl(file, line, '** Not Yet Implemented !! **')
end

# Loading all the Ruby project files.
dir_path = NSBundle.mainBundle.resourcePath.fileSystemRepresentation
Dir.entries(dir_path).each do |path|
  if path != File.basename(__FILE__) and path[-3..-1] == '.rb'
    require(path)
  end
end

# Starting the Cocoa main loop.
NSApplicationMain(0, nil)
